==> dynamodb-keyspace-0.0.6.tgz: package/dist-es/Table.js <==
import { DkClient } from './Client';
import { KeySpace } from './KeySpace';
export const primaryIndex = 'primaryIndex';
export class Table {
    constructor(config) {
        this.config = config;
        this.indexAttributeKeys = (index) => {
            const indexConfig = this.config.indexes[index];
            return indexConfig.sort ? [indexConfig.hash.key, indexConfig.sort.key] : [indexConfig.hash.key];
        };
        this.pickPrimaryIndexKey = (object) => {
            return Object.fromEntries(this.indexAttributeKeys(this.primaryIndex).map(key => [key, object[key]]));
        };
        this.client = config.client;
        this.dkClient = new DkClient(config.client);
        this.dkClient.setDefaults(this.config.defaults);
        this.dkClient.setMiddleware(this.config.middleware);
        this.tableName = this.config.name;
    }
    configure(config) {
        return new Table(config);
    }
    get KeySpace() {
        const ParentTable = new Table(this.config);
        return class TableKeySpace extends KeySpace {
            constructor() {
                super(ParentTable, {});
            }
        };
    }
    get indexes() {
        return Object.keys(this.config.indexes);
    }
    get primaryIndex() {
        return primaryIndex;
    }
    get secondaryIndexes() {
        return this.indexes.filter((index) => index !== this.primaryIndex);
    }
    get attributeKeys() {
        return this.indexes.flatMap(index => this.indexAttributeKeys(index));
    }
    omitIndexKeys(object) {
        const clone = { ...object };
        this.attributeKeys.forEach(key => {
            if (key in clone)
                delete clone[key];
        });
        return clone;
    }
}

==> dynamodb-keyspace-0.0.8.tgz: package/dist-es/Table.js <==
import { DkClient } from './Client';
import { KeySpace } from './KeySpace';
export const primaryIndex = 'primaryIndex';
export class Table {
    constructor(config) {
        this.config = config;
        this.indexAttributeKeys = (index) => {
            const indexConfig = this.config.indexes[index];
            return indexConfig.sort ? [indexConfig.hash.key, indexConfig.sort.key] : [indexConfig.hash.key];
        };
        this.pickPrimaryIndexKey = (object) => {
            return Object.fromEntries(this.indexAttributeKeys(this.primaryIndex).map(key => [key, object[key]]));
        };
        this.client = config.client;
        this.dkClient = new DkClient(config.client);
        this.dkClient.setDefaults(this.config.defaults);
        this.dkClient.setMiddleware(this.config.middleware);
        this.name = this.config.name;
    }
    configure(config) {
        return new Table(config);
    }
    get KeySpace() {
        const ParentTable = new Table(this.config);
        return class TableKeySpace extends KeySpace {
            constructor() {
                super(ParentTable, {});
            }
        };
    }
    get indexes() {
        return Object.keys(this.config.indexes);
    }
    get primaryIndex() {
        return primaryIndex;
    }
    get secondaryIndexes() {
        return this.indexes.filter((index) => index !== this.primaryIndex);
    }
    get attributeKeys() {
        return this.indexes.flatMap(index => this.indexAttributeKeys(index));
    }
    omitIndexKeys(object) {
        const clone = { ...object };
        this.attributeKeys.forEach(key => {
            if (key in clone)
                delete clone[key];
        });
        return clone;
    }
}
